RgbaOf

Struct RgbaOf 

#[repr(C)]
pub struct RgbaOf<T> { pub r: T, pub g: T, pub b: T, pub a: T, }

Fields

r: T

Red

g: T

Green

b: T

Blue

a: T

Alpha

Implementations

Source

impl<T> RgbaOf<T>

pub const LEN: usize = 4usize

pub const fn from_array(array: [T; 4]) -> RgbaOf<T>

pub const fn to_array(self) -> [T; 4]

pub const fn array(&self) -> &[T; 4]

pub const fn array_mut(&mut self) -> &mut [T; 4]

pub fn max(self, other: RgbaOf<T>) -> RgbaOf<T>
where RgbaOf<T>: Max,

Max function in a component way

Can cause a panic for grid if the size mismatch

pub fn min(self, other: RgbaOf<T>) -> RgbaOf<T>
where RgbaOf<T>: Min,

Min function in a component way

Can cause a panic for grid if the size mismatch

pub fn abs(self) -> <RgbaOf<T> as Abs>::Output
where RgbaOf<T>: Abs,

Absolute value in a component way.

Overflow behavior

The absolute value of iX::MIN cannot be represented as an iX, and attempting to calculate it will cause an overflow. This means that code in debug mode will trigger a panic on this case and optimized code will return iX::MIN without a panic.

Can cause a panic for grid if the size mismatch

pub fn mix<C>(self, other: RgbaOf<T>, coef: C) -> RgbaOf<T>
where RgbaOf<T>: Mix<C>, C: Float,

Mix function in a component way

The coef is clamped between 0.0..1.

  1. => self,
  2. => dest.

Can cause a panic for grid if the size mismatch

pub fn mix_unchecked<C>(self, other: RgbaOf<T>, coef: C) -> RgbaOf<T>
where RgbaOf<T>: Mix<C>, C: Float,

Mix function in a component way

The coef is not clamped between 0.0..1.

  1. => self,
  2. => dest.

Can cause a panic for grid if the size mismatch

pub fn clamp(self, min_val: RgbaOf<T>, max_val: RgbaOf<T>) -> RgbaOf<T>
where RgbaOf<T>: Clamp,

Clamp function in a component way

Clamps self between min_val and max_val (inclusive)

Can cause a panic for grid if the size mismatch

Source

impl<T> RgbaOf<T>

pub const R_INDEX: usize = 0

Red

pub const G_INDEX: usize = 1

Green

pub const B_INDEX: usize = 2

Blue

pub const A_INDEX: usize = 3

Alpha

pub const fn new(red: T, green: T, blue: T, alpha: T) -> RgbaOf<T>

pub const fn rgba(red: T, green: T, blue: T, alpha: T) -> RgbaOf<T>

pub const fn rgb(red: T, green: T, blue: T) -> RgbaOf<T>
where T: RangeDefault,

Alpha is at max

pub const fn gray(rgb: T) -> RgbaOf<T>
where T: RangeDefault + Copy,

Alpha is at max

pub const fn splat_rgba(rgba: T) -> RgbaOf<T>
where T: Copy,

pub const fn splat_rgb(rgb: T) -> RgbaOf<T>
where T: Copy + RangeDefault,

Alpha is at max

pub const fn splat_rgb_with_a(rgb: T, a: T) -> RgbaOf<T>
where T: Copy,

pub fn rgba_ref(&self) -> &[T; 4]

pub fn rgba_mut(&mut self) -> &mut [T; 4]

pub fn rgb_ref(&self) -> &[T; 3]

pub fn rgb_mut(&mut self) -> &mut [T; 3]

pub fn r(&self) -> T
where T: Copy,

Red

pub fn with_r(self, r: T) -> RgbaOf<T>
where T: Copy,

Red

pub fn set_r(&mut self, r: T) -> &mut RgbaOf<T>

Red

pub fn replace_r(self, r: T) -> T

Red

pub fn g(&self) -> T
where T: Copy,

Green

pub fn with_g(self, g: T) -> RgbaOf<T>
where T: Copy,

Green

pub fn set_g(&mut self, g: T) -> &mut RgbaOf<T>

Green

pub fn replace_g(self, g: T) -> T

Green

pub fn b(&self) -> T
where T: Copy,

Blue

pub fn with_b(self, b: T) -> RgbaOf<T>
where T: Copy,

Blue

pub fn set_b(&mut self, b: T) -> &mut RgbaOf<T>

Blue

pub fn replace_b(self, b: T) -> T

Blue

pub fn a(&self) -> T
where T: Copy,

Alpha

pub fn with_a(self, a: T) -> RgbaOf<T>
where T: Copy,

Alpha

pub fn set_a(&mut self, a: T) -> &mut RgbaOf<T>

Alpha

pub fn replace_a(self, a: T) -> T

Alpha

Source

impl<T> RgbaOf<T>
where T: Primitive,

pub fn to_rgba_of<R>(self) -> RgbaOf<R>
where R: Primitive + CastRangeFrom<T>,

pub fn to_hsla_of<R>(self) -> HslaOf<R>
where R: Float + CastRangeFrom<T>,