BitAnyPattern

Derive Macro BitAnyPattern 

#[derive(BitAnyPattern)]
{
    // Attributes available to this derive:
    #[hexga_bit]
}
Derive the BitAnyPattern trait for a struct

The macro ensures that the struct follows all the the safety requirements for the BitAnyPattern trait.

The following constraints need to be satisfied for the macro to succeed

  • All fields in the struct must to implement BitAnyPattern