Crate hexga Copy item path Source pub use hexga_generational as generational;pub use hexga_bitflags as bitflags;pub use hexga_math as math;prelude map_on A powerful macro to impl other macros for the given types. map_on_float f32, f64map_on_integer (i8, i16, i32, i64, isize) + (u8, u16, u32, u64, usize) map_on_integer_signed i8, i16, i32, i64, isizemap_on_integer_unsigned u8, u16, u32, u64, usizemap_on_number (i8, i16, i32, i64, isize) + (u8, u16, u32, u64, usize) + (f32, f64) map_on_number_and_bool (i8, i16, i32, i64, isize) + (u8, u16, u32, u64, usize) + (f32, f64) + (bool) OverflowBehavior ArithmeticNegative BitArithmetic For every type that support bit based operation (and &, or |, xor ^, not !, shift << / >>…) Capacity Clearable Clear the collection Decrease The -1 operation DefaultIsTripleUnderscore Uniform syntax : MyStruct::___() instead of MyStruct::default() Floating fX FromParallelIterator FromParallelIterator implements the creation of a collection
from a ParallelIterator . By implementing
FromParallelIterator for a given type, you define how it will be
created from an iterator.Get The collection have a quick way to access each element, where the index is copyable GetManyMut GetMut Half Define the 0.5 representation Increase The +1 operation IndexedParallelIterator An iterator that supports “random access” to its data, meaning
that you can split it at arbitrary indices and draw data from
those points. Integer uX or iX IntegerSigned iX IntegerUnsigned uX IntoParallelIterator IntoParallelIterator implements the conversion to a ParallelIterator .IntoParallelRefIterator IntoParallelRefIterator implements the conversion to a
ParallelIterator , providing shared references to the data.IntoParallelRefMutIterator IntoParallelRefMutIterator implements the conversion to a
ParallelIterator , providing mutable references to the data.Length MaxValue MinValue MinusOne Define the -1 representation NaNValue Define the Not a Number (NaN) representation Number +, -, *, /, %, 0, 1, ==, >=, min val, max val NumberArithmetic +, -, *, /, %, 0 NumberAttibute NumberNegative fX or iX One Define the 1 representation : The neutral element of the multiplication such that x * X::ONE = x ParallelBridge Conversion trait to convert an Iterator to a ParallelIterator. ParallelDrainFull ParallelDrainFull creates a parallel iterator that moves all items
from a collection while retaining the original capacity.ParallelDrainRange ParallelDrainRange creates a parallel iterator that moves a range of items
from a collection while retaining the original capacity.ParallelExtend ParallelExtend extends an existing collection with items from a ParallelIterator .ParallelIterator Parallel version of the standard iterator trait. ParallelSlice Parallel extensions for slices. ParallelSliceMut Parallel extensions for mutable slices. ParallelString Parallel extensions for strings. ResultExtension Useful to silence/convert to void some Err. ToDebug Toggleable UnitArithmetic +, -, 0 Zero Define the 0 representation : The absorbing element of the multiplication such that x * X::ZERO = X::ZERO ___ ___() is a shorthand for Default::default()half minus_one one zero