#[repr(C)]pub struct RgbaOf<T> {
pub r: T,
pub g: T,
pub b: T,
pub a: T,
}Fields
r: TRed
g: TGreen
b: TBlue
a: TAlpha
Implementations
Sourceimpl<T> RgbaOf<T>
impl<T> RgbaOf<T>
pub const LEN: usize = 4usize
pub const fn from_array(array: [T; 4]) -> RgbaOf<T>
pub const fn to_array(self) -> [T; 4]
pub const fn array(&self) -> &[T; 4]
pub const fn array_mut(&mut self) -> &mut [T; 4]
Sourcepub fn max(self, other: RgbaOf<T>) -> RgbaOf<T>
pub fn max(self, other: RgbaOf<T>) -> RgbaOf<T>
Max function in a component way
Can cause a panic for grid if the size mismatch
Sourcepub fn min(self, other: RgbaOf<T>) -> RgbaOf<T>
pub fn min(self, other: RgbaOf<T>) -> RgbaOf<T>
Min function in a component way
Can cause a panic for grid if the size mismatch
Sourcepub fn abs(self) -> <RgbaOf<T> as Abs>::Output
pub fn abs(self) -> <RgbaOf<T> as Abs>::Output
Absolute value in a component way.
Overflow behavior
The absolute value of iX::MIN cannot be represented as an iX, and attempting to calculate it will cause an overflow.
This means that code in debug mode will trigger a panic on this case and optimized code will return iX::MIN without a panic.
Can cause a panic for grid if the size mismatch
Sourcepub fn mix<C>(self, other: RgbaOf<T>, coef: C) -> RgbaOf<T>
pub fn mix<C>(self, other: RgbaOf<T>, coef: C) -> RgbaOf<T>
Mix function in a component way
The coef is clamped between 0.0..1.
- => self,
- => dest.
Can cause a panic for grid if the size mismatch
Sourcepub fn mix_unchecked<C>(self, other: RgbaOf<T>, coef: C) -> RgbaOf<T>
pub fn mix_unchecked<C>(self, other: RgbaOf<T>, coef: C) -> RgbaOf<T>
Mix function in a component way
The coef is not clamped between 0.0..1.
- => self,
- => dest.
Can cause a panic for grid if the size mismatch
Sourceimpl<T> RgbaOf<T>
impl<T> RgbaOf<T>
pub const fn new(red: T, green: T, blue: T, alpha: T) -> RgbaOf<T>
pub const fn rgba(red: T, green: T, blue: T, alpha: T) -> RgbaOf<T>
Sourcepub const fn rgb(red: T, green: T, blue: T) -> RgbaOf<T>where
T: RangeDefault,
pub const fn rgb(red: T, green: T, blue: T) -> RgbaOf<T>where
T: RangeDefault,
Alpha is at max
Sourcepub const fn gray(rgb: T) -> RgbaOf<T>where
T: RangeDefault + Copy,
pub const fn gray(rgb: T) -> RgbaOf<T>where
T: RangeDefault + Copy,
Alpha is at max
pub const fn splat_rgba(rgba: T) -> RgbaOf<T>where
T: Copy,
Sourcepub const fn splat_rgb(rgb: T) -> RgbaOf<T>where
T: Copy + RangeDefault,
pub const fn splat_rgb(rgb: T) -> RgbaOf<T>where
T: Copy + RangeDefault,
Alpha is at max
pub const fn splat_rgb_with_a(rgb: T, a: T) -> RgbaOf<T>where
T: Copy,
pub fn rgba_ref(&self) -> &[T; 4]
pub fn rgba_mut(&mut self) -> &mut [T; 4]
pub fn rgb_ref(&self) -> &[T; 3]
pub fn rgb_mut(&mut self) -> &mut [T; 3]
Sourceimpl<T> RgbaOf<T>where
T: Primitive,
impl<T> RgbaOf<T>where
T: Primitive,
pub fn to_rgba_of<R>(self) -> RgbaOf<R>where
R: Primitive + CastRangeFrom<T>,
pub fn to_hsla_of<R>(self) -> HslaOf<R>where
R: Float + CastRangeFrom<T>,